<?php

// Add support for SVG uploads
add_filter('upload_mimes', 'custom_upload_mimes');
function custom_upload_mimes($existing_mimes = array()) {
	$existing_mimes['svg'] = 'image/svg';

	return $existing_mimes;
}

// Add thumbnail support
if (function_exists('add_theme_support')) {
	add_theme_support('post-thumbnails');
	set_post_thumbnail_size(140, 140, true);
}

// Create custom post types
add_action('init', 'createCustomPostTypes');
function createCustomPostTypes() {
	$post_types = getCustomPostTypeNames();

	foreach ($post_types as $post_type) {
		$name = ucfirst($post_type);
		$singular_name = substr($name, 0, -1);
		$supports = $post_type == 'downloads' ? array('title', 'editor', 'thumbnail') : array('title', 'editor');

		$labels = array(
			'name' => _x($name, 'post type general name'),
			'singular_name' => _x($singular_name, 'post type singular name'),
			'add_new' => _x('Add New', $singular_name),
			'add_new_item' => __('Add New ' . $singular_name),
			'edit_item' => __('Edit ' . $singular_name),
			'new_item' => __('New ' . $singular_name),
			'view_item' => __('View ' . $singular_name),
			'search_items' => __('Search ' . $name),
			'not_found' =>  __('No ' . $post_type . ' found'),
			'not_found_in_trash' => __('No ' . $post_type . ' found in Trash'),
			'parent_item_colon' => '',
			'menu_name' => $name
		);

		$args = array(
			'labels' => $labels,
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'rewrite' => false,
			'query_var' => true,
			'capability_type' => 'post',
			'has_archive' => true,
			'hierarchical' => false,
			'menu_position' => 5,
			'supports' => $supports,
			'taxonomies' => getCustomTaxonomyNames()
		);

		register_post_type($post_type, $args);
	}
}

// Create custom taxonomies
add_action('init', 'createCustomTaxonomies');
function createCustomTaxonomies() {
	$taxonomies = getCustomTaxonomyNames();

	foreach ($taxonomies as $taxonomy) {
		$name = ucfirst($taxonomy);

		$labels = array(
			'name' => _x($name, 'taxonomy general name'),
			'singular_name' => _x($name, 'taxonomy singular name'),
			'search_items' =>  __('Search ' . $name),
			'all_items' => __('All ' . $name),
			'parent_item' => __('Parent ' . $name),
			'parent_item_colon' => __('Parent ' . $name . ':'),
			'edit_item' => __('Edit ' . $name),
			'update_item' => __('Update ' . $name),
			'add_new_item' => __('Add New ' . $name),
			'new_item_name' => __('New ' . $name . ' Name'),
			'menu_name' => __($name)
		);

		$args = array(
			'labels' => $labels,
			'hierarchical' => true,
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array('slug' => $taxonomy)
		);

		// Also associate custom taxonomies with pages
		$types = getCustomPostTypeNames();
		$types[] = 'page';

		register_taxonomy($taxonomy, $types, $args);
	}
}

function getCustomPostTypeNames() {
	//return array('guidelines', 'examples', 'downloads');
	return array('examples', 'downloads');
}

function getCustomTaxonomyNames() {
	return array('metadata');
}

function getPostAttachmentExtension($mime_type) {
	$split = split('/', $mime_type);

	return '.' . $split[1];
}

function getPostAttachmentFilesize($file, $digits = 1) {
	$file_size = filesize($file);
    $sizes = array('TB','GB','MB','KB','B');
    $total = count($sizes);
    while ($total-- && $file_size > 1024) {
		$file_size /= 1024;
	}

	return round($file_size, $digits) . ' ' . $sizes[$total];
}


if ( is_page('downloads') ) {
	remove_filter('the_content', 'wpautop');
}

?>